
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
from ....tensorflow.core.framework import variable_pb2 as tensorflow_dot_core_dot_framework_dot_variable__pb2
from ....tensorflow.core.framework import versions_pb2 as tensorflow_dot_core_dot_framework_dot_versions__pb2
from ....tensorflow.core.protobuf import struct_pb2 as tensorflow_dot_core_dot_protobuf_dot_struct__pb2
from ....tensorflow.core.protobuf import trackable_object_graph_pb2 as tensorflow_dot_core_dot_protobuf_dot_trackable__object__graph__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/saved_object_graph.proto', package='tensorflow', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n1tensorflow/core/protobuf/saved_object_graph.proto\x12\ntensorflow\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto\x1a(tensorflow/core/framework/variable.proto\x1a(tensorflow/core/framework/versions.proto\x1a%tensorflow/core/protobuf/struct.proto\x1a5tensorflow/core/protobuf/trackable_object_graph.proto"\xe8\x01\n\x10SavedObjectGraph\x12&\n\x05nodes\x18\x01 \x03(\x0b2\x17.tensorflow.SavedObject\x12O\n\x12concrete_functions\x18\x02 \x03(\x0b23.tensorflow.SavedObjectGraph.ConcreteFunctionsEntry\x1a[\n\x16ConcreteFunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x120\n\x05value\x18\x02 \x01(\x0b2!.tensorflow.SavedConcreteFunction:\x028\x01"\x90\x06\n\x0bSavedObject\x12R\n\x08children\x18\x01 \x03(\x0b2@.tensorflow.TrackableObjectGraph.TrackableObject.ObjectReference\x12^\n\x0eslot_variables\x18\x03 \x03(\x0b2F.tensorflow.TrackableObjectGraph.TrackableObject.SlotVariableReference\x122\n\x0buser_object\x18\x04 \x01(\x0b2\x1b.tensorflow.SavedUserObjectH\x00\x12\'\n\x05asset\x18\x05 \x01(\x0b2\x16.tensorflow.SavedAssetH\x00\x12-\n\x08function\x18\x06 \x01(\x0b2\x19.tensorflow.SavedFunctionH\x00\x12-\n\x08variable\x18\x07 \x01(\x0b2\x19.tensorflow.SavedVariableH\x00\x12G\n\x16bare_concrete_function\x18\x08 \x01(\x0b2%.tensorflow.SavedBareConcreteFunctionH\x00\x12-\n\x08constant\x18\t \x01(\x0b2\x19.tensorflow.SavedConstantH\x00\x12-\n\x08resource\x18\n \x01(\x0b2\x19.tensorflow.SavedResourceH\x00\x125\n\x0fcaptured_tensor\x18\x0c \x01(\x0b2\x1a.tensorflow.CapturedTensorH\x00\x12F\n\x10saveable_objects\x18\x0b \x03(\x0b2,.tensorflow.SavedObject.SaveableObjectsEntry\x1aR\n\x14SaveableObjectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b2\x1a.tensorflow.SaveableObject:\x028\x01B\x06\n\x04kindJ\x04\x08\x02\x10\x03R\nattributes"d\n\x0fSavedUserObject\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\'\n\x07version\x18\x02 \x01(\x0b2\x16.tensorflow.VersionDef\x12\x14\n\x08metadata\x18\x03 \x01(\tB\x02\x18\x01"*\n\nSavedAsset\x12\x1c\n\x14asset_file_def_index\x18\x01 \x01(\x05"\\\n\rSavedFunction\x12\x1a\n\x12concrete_functions\x18\x01 \x03(\t\x12/\n\rfunction_spec\x18\x02 \x01(\x0b2\x18.tensorflow.FunctionSpec"9\n\x0eCapturedTensor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11concrete_function\x18\x02 \x01(\t"\xa8\x01\n\x15SavedConcreteFunction\x12\x14\n\x0cbound_inputs\x18\x02 \x03(\x05\x12B\n\x1dcanonicalized_input_signature\x18\x03 \x01(\x0b2\x1b.tensorflow.StructuredValue\x125\n\x10output_signature\x18\x04 \x01(\x0b2\x1b.tensorflow.StructuredValue"\xad\x01\n\x19SavedBareConcreteFunction\x12\x1e\n\x16concrete_function_name\x18\x01 \x01(\t\x12\x19\n\x11argument_keywords\x18\x02 \x03(\t\x12$\n\x1callowed_positional_arguments\x18\x03 \x01(\x03\x12/\n\rfunction_spec\x18\x04 \x01(\x0b2\x18.tensorflow.FunctionSpec""\n\rSavedConstant\x12\x11\n\toperation\x18\x01 \x01(\t"\xd7\x02\n\rSavedVariable\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12\x11\n\ttrainable\x18\x03 \x01(\x08\x12<\n\x0fsynchronization\x18\x04 \x01(\x0e2#.tensorflow.VariableSynchronization\x124\n\x0baggregation\x18\x05 \x01(\x0e2\x1f.tensorflow.VariableAggregation\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06device\x18\x07 \x01(\t\x12O\n,experimental_distributed_variable_components\x18\x08 \x03(\x0b2\x19.tensorflow.SavedVariable"\xfb\x01\n\x0cFunctionSpec\x120\n\x0bfullargspec\x18\x01 \x01(\x0b2\x1b.tensorflow.StructuredValue\x12\x11\n\tis_method\x18\x02 \x01(\x08\x124\n\x0finput_signature\x18\x05 \x01(\x0b2\x1b.tensorflow.StructuredValue\x128\n\x0bjit_compile\x18\x06 \x01(\x0e2#.tensorflow.FunctionSpec.JitCompile"*\n\nJitCompile\x12\x0b\n\x07DEFAULT\x10\x00\x12\x06\n\x02ON\x10\x01\x12\x07\n\x03OFF\x10\x02J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05"\x1f\n\rSavedResource\x12\x0e\n\x06device\x18\x01 \x01(\t"A\n\x0eSaveableObject\x12\x15\n\rsave_function\x18\x02 \x01(\x05\x12\x18\n\x10restore_function\x18\x03 \x01(\x05BZZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_variable__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_versions__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_struct__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_trackable__object__graph__pb2.DESCRIPTOR])
_FUNCTIONSPEC_JITCOMPILE = _descriptor.EnumDescriptor(name='JitCompile', full_name='tensorflow.FunctionSpec.JitCompile', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='DEFAULT', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='ON', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='OFF', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=2576, serialized_end=2618)
_sym_db.RegisterEnumDescriptor(_FUNCTIONSPEC_JITCOMPILE)
_SAVEDOBJECTGRAPH_CONCRETEFUNCTIONSENTRY = _descriptor.Descriptor(name='ConcreteFunctionsEntry', full_name='tensorflow.SavedObjectGraph.ConcreteFunctionsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.SavedObjectGraph.ConcreteFunctionsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.SavedObjectGraph.ConcreteFunctionsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=470, serialized_end=561)
_SAVEDOBJECTGRAPH = _descriptor.Descriptor(name='SavedObjectGraph', full_name='tensorflow.SavedObjectGraph', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='nodes', full_name='tensorflow.SavedObjectGraph.nodes', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='concrete_functions', full_name='tensorflow.SavedObjectGraph.concrete_functions', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_SAVEDOBJECTGRAPH_CONCRETEFUNCTIONSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=329, serialized_end=561)
_SAVEDOBJECT_SAVEABLEOBJECTSENTRY = _descriptor.Descriptor(name='SaveableObjectsEntry', full_name='tensorflow.SavedObject.SaveableObjectsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.SavedObject.SaveableObjectsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.SavedObject.SaveableObjectsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1240, serialized_end=1322)
_SAVEDOBJECT = _descriptor.Descriptor(name='SavedObject', full_name='tensorflow.SavedObject', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='children', full_name='tensorflow.SavedObject.children', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='slot_variables', full_name='tensorflow.SavedObject.slot_variables', index=1, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='user_object', full_name='tensorflow.SavedObject.user_object', index=2, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='asset', full_name='tensorflow.SavedObject.asset', index=3, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='function', full_name='tensorflow.SavedObject.function', index=4, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='variable', full_name='tensorflow.SavedObject.variable', index=5, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bare_concrete_function', full_name='tensorflow.SavedObject.bare_concrete_function', index=6, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='constant', full_name='tensorflow.SavedObject.constant', index=7, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='resource', full_name='tensorflow.SavedObject.resource', index=8, number=10, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='captured_tensor', full_name='tensorflow.SavedObject.captured_tensor', index=9, number=12, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='saveable_objects', full_name='tensorflow.SavedObject.saveable_objects', index=10, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_SAVEDOBJECT_SAVEABLEOBJECTSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='kind', full_name='tensorflow.SavedObject.kind', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=564, serialized_end=1348)
_SAVEDUSEROBJECT = _descriptor.Descriptor(name='SavedUserObject', full_name='tensorflow.SavedUserObject', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='identifier', full_name='tensorflow.SavedUserObject.identifier', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='version', full_name='tensorflow.SavedUserObject.version', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.SavedUserObject.metadata', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1350, serialized_end=1450)
_SAVEDASSET = _descriptor.Descriptor(name='SavedAsset', full_name='tensorflow.SavedAsset', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='asset_file_def_index', full_name='tensorflow.SavedAsset.asset_file_def_index', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1452, serialized_end=1494)
_SAVEDFUNCTION = _descriptor.Descriptor(name='SavedFunction', full_name='tensorflow.SavedFunction', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='concrete_functions', full_name='tensorflow.SavedFunction.concrete_functions', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='function_spec', full_name='tensorflow.SavedFunction.function_spec', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1496, serialized_end=1588)
_CAPTUREDTENSOR = _descriptor.Descriptor(name='CapturedTensor', full_name='tensorflow.CapturedTensor', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.CapturedTensor.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='concrete_function', full_name='tensorflow.CapturedTensor.concrete_function', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1590, serialized_end=1647)
_SAVEDCONCRETEFUNCTION = _descriptor.Descriptor(name='SavedConcreteFunction', full_name='tensorflow.SavedConcreteFunction', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='bound_inputs', full_name='tensorflow.SavedConcreteFunction.bound_inputs', index=0, number=2, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='canonicalized_input_signature', full_name='tensorflow.SavedConcreteFunction.canonicalized_input_signature', index=1, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_signature', full_name='tensorflow.SavedConcreteFunction.output_signature', index=2, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1650, serialized_end=1818)
_SAVEDBARECONCRETEFUNCTION = _descriptor.Descriptor(name='SavedBareConcreteFunction', full_name='tensorflow.SavedBareConcreteFunction', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='concrete_function_name', full_name='tensorflow.SavedBareConcreteFunction.concrete_function_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='argument_keywords', full_name='tensorflow.SavedBareConcreteFunction.argument_keywords', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allowed_positional_arguments', full_name='tensorflow.SavedBareConcreteFunction.allowed_positional_arguments', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='function_spec', full_name='tensorflow.SavedBareConcreteFunction.function_spec', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1821, serialized_end=1994)
_SAVEDCONSTANT = _descriptor.Descriptor(name='SavedConstant', full_name='tensorflow.SavedConstant', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='operation', full_name='tensorflow.SavedConstant.operation', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1996, serialized_end=2030)
_SAVEDVARIABLE = _descriptor.Descriptor(name='SavedVariable', full_name='tensorflow.SavedVariable', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.SavedVariable.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.SavedVariable.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='trainable', full_name='tensorflow.SavedVariable.trainable', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='synchronization', full_name='tensorflow.SavedVariable.synchronization', index=3, number=4, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='aggregation', full_name='tensorflow.SavedVariable.aggregation', index=4, number=5, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.SavedVariable.name', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device', full_name='tensorflow.SavedVariable.device', index=6, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='experimental_distributed_variable_components', full_name='tensorflow.SavedVariable.experimental_distributed_variable_components', index=7, number=8, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2033, serialized_end=2376)
_FUNCTIONSPEC = _descriptor.Descriptor(name='FunctionSpec', full_name='tensorflow.FunctionSpec', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='fullargspec', full_name='tensorflow.FunctionSpec.fullargspec', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_method', full_name='tensorflow.FunctionSpec.is_method', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_signature', full_name='tensorflow.FunctionSpec.input_signature', index=2, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='jit_compile', full_name='tensorflow.FunctionSpec.jit_compile', index=3, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_FUNCTIONSPEC_JITCOMPILE], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2379, serialized_end=2630)
_SAVEDRESOURCE = _descriptor.Descriptor(name='SavedResource', full_name='tensorflow.SavedResource', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device', full_name='tensorflow.SavedResource.device', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2632, serialized_end=2663)
_SAVEABLEOBJECT = _descriptor.Descriptor(name='SaveableObject', full_name='tensorflow.SaveableObject', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='save_function', full_name='tensorflow.SaveableObject.save_function', index=0, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='restore_function', full_name='tensorflow.SaveableObject.restore_function', index=1, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2665, serialized_end=2730)
_SAVEDOBJECTGRAPH_CONCRETEFUNCTIONSENTRY.fields_by_name['value'].message_type = _SAVEDCONCRETEFUNCTION
_SAVEDOBJECTGRAPH_CONCRETEFUNCTIONSENTRY.containing_type = _SAVEDOBJECTGRAPH
_SAVEDOBJECTGRAPH.fields_by_name['nodes'].message_type = _SAVEDOBJECT
_SAVEDOBJECTGRAPH.fields_by_name['concrete_functions'].message_type = _SAVEDOBJECTGRAPH_CONCRETEFUNCTIONSENTRY
_SAVEDOBJECT_SAVEABLEOBJECTSENTRY.fields_by_name['value'].message_type = _SAVEABLEOBJECT
_SAVEDOBJECT_SAVEABLEOBJECTSENTRY.containing_type = _SAVEDOBJECT
_SAVEDOBJECT.fields_by_name['children'].message_type = tensorflow_dot_core_dot_protobuf_dot_trackable__object__graph__pb2._TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_OBJECTREFERENCE
_SAVEDOBJECT.fields_by_name['slot_variables'].message_type = tensorflow_dot_core_dot_protobuf_dot_trackable__object__graph__pb2._TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SLOTVARIABLEREFERENCE
_SAVEDOBJECT.fields_by_name['user_object'].message_type = _SAVEDUSEROBJECT
_SAVEDOBJECT.fields_by_name['asset'].message_type = _SAVEDASSET
_SAVEDOBJECT.fields_by_name['function'].message_type = _SAVEDFUNCTION
_SAVEDOBJECT.fields_by_name['variable'].message_type = _SAVEDVARIABLE
_SAVEDOBJECT.fields_by_name['bare_concrete_function'].message_type = _SAVEDBARECONCRETEFUNCTION
_SAVEDOBJECT.fields_by_name['constant'].message_type = _SAVEDCONSTANT
_SAVEDOBJECT.fields_by_name['resource'].message_type = _SAVEDRESOURCE
_SAVEDOBJECT.fields_by_name['captured_tensor'].message_type = _CAPTUREDTENSOR
_SAVEDOBJECT.fields_by_name['saveable_objects'].message_type = _SAVEDOBJECT_SAVEABLEOBJECTSENTRY
_SAVEDOBJECT.oneofs_by_name['kind'].fields.append(_SAVEDOBJECT.fields_by_name['user_object'])
_SAVEDOBJECT.fields_by_name['user_object'].containing_oneof = _SAVEDOBJECT.oneofs_by_name['kind']
_SAVEDOBJECT.oneofs_by_name['kind'].fields.append(_SAVEDOBJECT.fields_by_name['asset'])
_SAVEDOBJECT.fields_by_name['asset'].containing_oneof = _SAVEDOBJECT.oneofs_by_name['kind']
_SAVEDOBJECT.oneofs_by_name['kind'].fields.append(_SAVEDOBJECT.fields_by_name['function'])
_SAVEDOBJECT.fields_by_name['function'].containing_oneof = _SAVEDOBJECT.oneofs_by_name['kind']
_SAVEDOBJECT.oneofs_by_name['kind'].fields.append(_SAVEDOBJECT.fields_by_name['variable'])
_SAVEDOBJECT.fields_by_name['variable'].containing_oneof = _SAVEDOBJECT.oneofs_by_name['kind']
_SAVEDOBJECT.oneofs_by_name['kind'].fields.append(_SAVEDOBJECT.fields_by_name['bare_concrete_function'])
_SAVEDOBJECT.fields_by_name['bare_concrete_function'].containing_oneof = _SAVEDOBJECT.oneofs_by_name['kind']
_SAVEDOBJECT.oneofs_by_name['kind'].fields.append(_SAVEDOBJECT.fields_by_name['constant'])
_SAVEDOBJECT.fields_by_name['constant'].containing_oneof = _SAVEDOBJECT.oneofs_by_name['kind']
_SAVEDOBJECT.oneofs_by_name['kind'].fields.append(_SAVEDOBJECT.fields_by_name['resource'])
_SAVEDOBJECT.fields_by_name['resource'].containing_oneof = _SAVEDOBJECT.oneofs_by_name['kind']
_SAVEDOBJECT.oneofs_by_name['kind'].fields.append(_SAVEDOBJECT.fields_by_name['captured_tensor'])
_SAVEDOBJECT.fields_by_name['captured_tensor'].containing_oneof = _SAVEDOBJECT.oneofs_by_name['kind']
_SAVEDUSEROBJECT.fields_by_name['version'].message_type = tensorflow_dot_core_dot_framework_dot_versions__pb2._VERSIONDEF
_SAVEDFUNCTION.fields_by_name['function_spec'].message_type = _FUNCTIONSPEC
_SAVEDCONCRETEFUNCTION.fields_by_name['canonicalized_input_signature'].message_type = tensorflow_dot_core_dot_protobuf_dot_struct__pb2._STRUCTUREDVALUE
_SAVEDCONCRETEFUNCTION.fields_by_name['output_signature'].message_type = tensorflow_dot_core_dot_protobuf_dot_struct__pb2._STRUCTUREDVALUE
_SAVEDBARECONCRETEFUNCTION.fields_by_name['function_spec'].message_type = _FUNCTIONSPEC
_SAVEDVARIABLE.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_SAVEDVARIABLE.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_SAVEDVARIABLE.fields_by_name['synchronization'].enum_type = tensorflow_dot_core_dot_framework_dot_variable__pb2._VARIABLESYNCHRONIZATION
_SAVEDVARIABLE.fields_by_name['aggregation'].enum_type = tensorflow_dot_core_dot_framework_dot_variable__pb2._VARIABLEAGGREGATION
_SAVEDVARIABLE.fields_by_name['experimental_distributed_variable_components'].message_type = _SAVEDVARIABLE
_FUNCTIONSPEC.fields_by_name['fullargspec'].message_type = tensorflow_dot_core_dot_protobuf_dot_struct__pb2._STRUCTUREDVALUE
_FUNCTIONSPEC.fields_by_name['input_signature'].message_type = tensorflow_dot_core_dot_protobuf_dot_struct__pb2._STRUCTUREDVALUE
_FUNCTIONSPEC.fields_by_name['jit_compile'].enum_type = _FUNCTIONSPEC_JITCOMPILE
_FUNCTIONSPEC_JITCOMPILE.containing_type = _FUNCTIONSPEC
DESCRIPTOR.message_types_by_name['SavedObjectGraph'] = _SAVEDOBJECTGRAPH
DESCRIPTOR.message_types_by_name['SavedObject'] = _SAVEDOBJECT
DESCRIPTOR.message_types_by_name['SavedUserObject'] = _SAVEDUSEROBJECT
DESCRIPTOR.message_types_by_name['SavedAsset'] = _SAVEDASSET
DESCRIPTOR.message_types_by_name['SavedFunction'] = _SAVEDFUNCTION
DESCRIPTOR.message_types_by_name['CapturedTensor'] = _CAPTUREDTENSOR
DESCRIPTOR.message_types_by_name['SavedConcreteFunction'] = _SAVEDCONCRETEFUNCTION
DESCRIPTOR.message_types_by_name['SavedBareConcreteFunction'] = _SAVEDBARECONCRETEFUNCTION
DESCRIPTOR.message_types_by_name['SavedConstant'] = _SAVEDCONSTANT
DESCRIPTOR.message_types_by_name['SavedVariable'] = _SAVEDVARIABLE
DESCRIPTOR.message_types_by_name['FunctionSpec'] = _FUNCTIONSPEC
DESCRIPTOR.message_types_by_name['SavedResource'] = _SAVEDRESOURCE
DESCRIPTOR.message_types_by_name['SaveableObject'] = _SAVEABLEOBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
SavedObjectGraph = _reflection.GeneratedProtocolMessageType('SavedObjectGraph', (_message.Message,), {'ConcreteFunctionsEntry': _reflection.GeneratedProtocolMessageType('ConcreteFunctionsEntry', (_message.Message,), {'DESCRIPTOR': _SAVEDOBJECTGRAPH_CONCRETEFUNCTIONSENTRY, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'}), 'DESCRIPTOR': _SAVEDOBJECTGRAPH, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SavedObjectGraph)
_sym_db.RegisterMessage(SavedObjectGraph.ConcreteFunctionsEntry)
SavedObject = _reflection.GeneratedProtocolMessageType('SavedObject', (_message.Message,), {'SaveableObjectsEntry': _reflection.GeneratedProtocolMessageType('SaveableObjectsEntry', (_message.Message,), {'DESCRIPTOR': _SAVEDOBJECT_SAVEABLEOBJECTSENTRY, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'}), 'DESCRIPTOR': _SAVEDOBJECT, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SavedObject)
_sym_db.RegisterMessage(SavedObject.SaveableObjectsEntry)
SavedUserObject = _reflection.GeneratedProtocolMessageType('SavedUserObject', (_message.Message,), {'DESCRIPTOR': _SAVEDUSEROBJECT, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SavedUserObject)
SavedAsset = _reflection.GeneratedProtocolMessageType('SavedAsset', (_message.Message,), {'DESCRIPTOR': _SAVEDASSET, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SavedAsset)
SavedFunction = _reflection.GeneratedProtocolMessageType('SavedFunction', (_message.Message,), {'DESCRIPTOR': _SAVEDFUNCTION, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SavedFunction)
CapturedTensor = _reflection.GeneratedProtocolMessageType('CapturedTensor', (_message.Message,), {'DESCRIPTOR': _CAPTUREDTENSOR, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(CapturedTensor)
SavedConcreteFunction = _reflection.GeneratedProtocolMessageType('SavedConcreteFunction', (_message.Message,), {'DESCRIPTOR': _SAVEDCONCRETEFUNCTION, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SavedConcreteFunction)
SavedBareConcreteFunction = _reflection.GeneratedProtocolMessageType('SavedBareConcreteFunction', (_message.Message,), {'DESCRIPTOR': _SAVEDBARECONCRETEFUNCTION, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SavedBareConcreteFunction)
SavedConstant = _reflection.GeneratedProtocolMessageType('SavedConstant', (_message.Message,), {'DESCRIPTOR': _SAVEDCONSTANT, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SavedConstant)
SavedVariable = _reflection.GeneratedProtocolMessageType('SavedVariable', (_message.Message,), {'DESCRIPTOR': _SAVEDVARIABLE, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SavedVariable)
FunctionSpec = _reflection.GeneratedProtocolMessageType('FunctionSpec', (_message.Message,), {'DESCRIPTOR': _FUNCTIONSPEC, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(FunctionSpec)
SavedResource = _reflection.GeneratedProtocolMessageType('SavedResource', (_message.Message,), {'DESCRIPTOR': _SAVEDRESOURCE, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SavedResource)
SaveableObject = _reflection.GeneratedProtocolMessageType('SaveableObject', (_message.Message,), {'DESCRIPTOR': _SAVEABLEOBJECT, '__module__': 'tensorflow.core.protobuf.saved_object_graph_pb2'})
_sym_db.RegisterMessage(SaveableObject)
DESCRIPTOR._options = None
_SAVEDOBJECTGRAPH_CONCRETEFUNCTIONSENTRY._options = None
_SAVEDOBJECT_SAVEABLEOBJECTSENTRY._options = None
_SAVEDUSEROBJECT.fields_by_name['metadata']._options = None




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.framework import graph_pb2 as tensorflow_dot_core_dot_framework_dot_graph__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/data/service/common.proto', package='tensorflow.data', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n)tensorflow/core/data/service/common.proto\x12\x0ftensorflow.data\x1a%tensorflow/core/framework/graph.proto"1\n\nDatasetDef\x12#\n\x05graph\x18\x01 \x01(\x0b2\x14.tensorflow.GraphDef"\xb2\x02\n\x07TaskDef\x122\n\x0bdataset_def\x18\x01 \x01(\x0b2\x1b.tensorflow.data.DatasetDefH\x00\x12\x0e\n\x04path\x18\x02 \x01(\tH\x00\x12\x12\n\ndataset_id\x18\x03 \x01(\x03\x12\x0f\n\x07task_id\x18\x04 \x01(\x03\x12\x0e\n\x06job_id\x18\x05 \x01(\x03\x12\x1b\n\x13num_split_providers\x18\t \x01(\x03\x12\x16\n\x0eworker_address\x18\x08 \x01(\t\x12;\n\x0fprocessing_mode\x18\x06 \x01(\x0e2".tensorflow.data.ProcessingModeDef\x12\x17\n\rnum_consumers\x18\x07 \x01(\x03H\x01B\t\n\x07datasetB\x18\n\x16optional_num_consumers"u\n\x08TaskInfo\x12\x16\n\x0eworker_address\x18\x01 \x01(\t\x12\x18\n\x10transfer_address\x18\x04 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x03\x12\x0e\n\x06job_id\x18\x03 \x01(\x03\x12\x16\n\x0estarting_round\x18\x05 \x01(\x03*L\n\x11ProcessingModeDef\x12\x0b\n\x07INVALID\x10\x00\x12\x13\n\x0fPARALLEL_EPOCHS\x10\x01\x12\x15\n\x11DISTRIBUTED_EPOCH\x10\x02b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_graph__pb2.DESCRIPTOR])
_PROCESSINGMODEDEF = _descriptor.EnumDescriptor(name='ProcessingModeDef', full_name='tensorflow.data.ProcessingModeDef', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='PARALLEL_EPOCHS', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DISTRIBUTED_EPOCH', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=580, serialized_end=656)
_sym_db.RegisterEnumDescriptor(_PROCESSINGMODEDEF)
ProcessingModeDef = enum_type_wrapper.EnumTypeWrapper(_PROCESSINGMODEDEF)
INVALID = 0
PARALLEL_EPOCHS = 1
DISTRIBUTED_EPOCH = 2
_DATASETDEF = _descriptor.Descriptor(name='DatasetDef', full_name='tensorflow.data.DatasetDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='graph', full_name='tensorflow.data.DatasetDef.graph', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=101, serialized_end=150)
_TASKDEF = _descriptor.Descriptor(name='TaskDef', full_name='tensorflow.data.TaskDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset_def', full_name='tensorflow.data.TaskDef.dataset_def', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='path', full_name='tensorflow.data.TaskDef.path', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dataset_id', full_name='tensorflow.data.TaskDef.dataset_id', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='task_id', full_name='tensorflow.data.TaskDef.task_id', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_id', full_name='tensorflow.data.TaskDef.job_id', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_split_providers', full_name='tensorflow.data.TaskDef.num_split_providers', index=5, number=9, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='worker_address', full_name='tensorflow.data.TaskDef.worker_address', index=6, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='processing_mode', full_name='tensorflow.data.TaskDef.processing_mode', index=7, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_consumers', full_name='tensorflow.data.TaskDef.num_consumers', index=8, number=7, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='dataset', full_name='tensorflow.data.TaskDef.dataset', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_num_consumers', full_name='tensorflow.data.TaskDef.optional_num_consumers', index=1, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=153, serialized_end=459)
_TASKINFO = _descriptor.Descriptor(name='TaskInfo', full_name='tensorflow.data.TaskInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='worker_address', full_name='tensorflow.data.TaskInfo.worker_address', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transfer_address', full_name='tensorflow.data.TaskInfo.transfer_address', index=1, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='task_id', full_name='tensorflow.data.TaskInfo.task_id', index=2, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_id', full_name='tensorflow.data.TaskInfo.job_id', index=3, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='starting_round', full_name='tensorflow.data.TaskInfo.starting_round', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=461, serialized_end=578)
_DATASETDEF.fields_by_name['graph'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_TASKDEF.fields_by_name['dataset_def'].message_type = _DATASETDEF
_TASKDEF.fields_by_name['processing_mode'].enum_type = _PROCESSINGMODEDEF
_TASKDEF.oneofs_by_name['dataset'].fields.append(_TASKDEF.fields_by_name['dataset_def'])
_TASKDEF.fields_by_name['dataset_def'].containing_oneof = _TASKDEF.oneofs_by_name['dataset']
_TASKDEF.oneofs_by_name['dataset'].fields.append(_TASKDEF.fields_by_name['path'])
_TASKDEF.fields_by_name['path'].containing_oneof = _TASKDEF.oneofs_by_name['dataset']
_TASKDEF.oneofs_by_name['optional_num_consumers'].fields.append(_TASKDEF.fields_by_name['num_consumers'])
_TASKDEF.fields_by_name['num_consumers'].containing_oneof = _TASKDEF.oneofs_by_name['optional_num_consumers']
DESCRIPTOR.message_types_by_name['DatasetDef'] = _DATASETDEF
DESCRIPTOR.message_types_by_name['TaskDef'] = _TASKDEF
DESCRIPTOR.message_types_by_name['TaskInfo'] = _TASKINFO
DESCRIPTOR.enum_types_by_name['ProcessingModeDef'] = _PROCESSINGMODEDEF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DatasetDef = _reflection.GeneratedProtocolMessageType('DatasetDef', (_message.Message,), {'DESCRIPTOR': _DATASETDEF, '__module__': 'tensorflow.core.data.service.common_pb2'})
_sym_db.RegisterMessage(DatasetDef)
TaskDef = _reflection.GeneratedProtocolMessageType('TaskDef', (_message.Message,), {'DESCRIPTOR': _TASKDEF, '__module__': 'tensorflow.core.data.service.common_pb2'})
_sym_db.RegisterMessage(TaskDef)
TaskInfo = _reflection.GeneratedProtocolMessageType('TaskInfo', (_message.Message,), {'DESCRIPTOR': _TASKINFO, '__module__': 'tensorflow.core.data.service.common_pb2'})
_sym_db.RegisterMessage(TaskInfo)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/cost_graph.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0fCostGraphProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/cost_graph_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n*tensorflow/core/framework/cost_graph.proto\x12\ntensorflow\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"\xca\x06\n\x0cCostGraphDef\x12+\n\x04node\x18\x01 \x03(\x0b2\x1d.tensorflow.CostGraphDef.Node\x125\n\x04cost\x18\x02 \x03(\x0b2\'.tensorflow.CostGraphDef.AggregatedCost\x1a\xa2\x05\n\x04Node\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06device\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x05\x12;\n\ninput_info\x18\x04 \x03(\x0b2\'.tensorflow.CostGraphDef.Node.InputInfo\x12=\n\x0boutput_info\x18\x05 \x03(\x0b2(.tensorflow.CostGraphDef.Node.OutputInfo\x12\x1d\n\x15temporary_memory_size\x18\x06 \x01(\x03\x12\x1e\n\x16persistent_memory_size\x18\x0c \x01(\x03\x12!\n\x15host_temp_memory_size\x18\n \x01(\x03B\x02\x18\x01\x12#\n\x17device_temp_memory_size\x18\x0b \x01(\x03B\x02\x18\x01\x12)\n\x1ddevice_persistent_memory_size\x18\x10 \x01(\x03B\x02\x18\x01\x12\x14\n\x0ccompute_cost\x18\t \x01(\x03\x12\x14\n\x0ccompute_time\x18\x0e \x01(\x03\x12\x13\n\x0bmemory_time\x18\x0f \x01(\x03\x12\x10\n\x08is_final\x18\x07 \x01(\x08\x12\x15\n\rcontrol_input\x18\x08 \x03(\x05\x12\x12\n\ninaccurate\x18\x11 \x01(\x08\x1a;\n\tInputInfo\x12\x16\n\x0epreceding_node\x18\x01 \x01(\x05\x12\x16\n\x0epreceding_port\x18\x02 \x01(\x05\x1a\x86\x01\n\nOutputInfo\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\x18\n\x10alias_input_port\x18\x02 \x01(\x03\x12+\n\x05shape\x18\x03 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12#\n\x05dtype\x18\x04 \x01(\x0e2\x14.tensorflow.DataType\x1a1\n\x0eAggregatedCost\x12\x0c\n\x04cost\x18\x01 \x01(\x02\x12\x11\n\tdimension\x18\x02 \x01(\tB\x83\x01\n\x18org.tensorflow.frameworkB\x0fCostGraphProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/cost_graph_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_COSTGRAPHDEF_NODE_INPUTINFO = _descriptor.Descriptor(name='InputInfo', full_name='tensorflow.CostGraphDef.Node.InputInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='preceding_node', full_name='tensorflow.CostGraphDef.Node.InputInfo.preceding_node', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='preceding_port', full_name='tensorflow.CostGraphDef.Node.InputInfo.preceding_port', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=739, serialized_end=798)
_COSTGRAPHDEF_NODE_OUTPUTINFO = _descriptor.Descriptor(name='OutputInfo', full_name='tensorflow.CostGraphDef.Node.OutputInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='size', full_name='tensorflow.CostGraphDef.Node.OutputInfo.size', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='alias_input_port', full_name='tensorflow.CostGraphDef.Node.OutputInfo.alias_input_port', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.CostGraphDef.Node.OutputInfo.shape', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.CostGraphDef.Node.OutputInfo.dtype', index=3, number=4, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=801, serialized_end=935)
_COSTGRAPHDEF_NODE = _descriptor.Descriptor(name='Node', full_name='tensorflow.CostGraphDef.Node', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.CostGraphDef.Node.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device', full_name='tensorflow.CostGraphDef.Node.device', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='id', full_name='tensorflow.CostGraphDef.Node.id', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_info', full_name='tensorflow.CostGraphDef.Node.input_info', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_info', full_name='tensorflow.CostGraphDef.Node.output_info', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='temporary_memory_size', full_name='tensorflow.CostGraphDef.Node.temporary_memory_size', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='persistent_memory_size', full_name='tensorflow.CostGraphDef.Node.persistent_memory_size', index=6, number=12, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_temp_memory_size', full_name='tensorflow.CostGraphDef.Node.host_temp_memory_size', index=7, number=10, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_temp_memory_size', full_name='tensorflow.CostGraphDef.Node.device_temp_memory_size', index=8, number=11, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_persistent_memory_size', full_name='tensorflow.CostGraphDef.Node.device_persistent_memory_size', index=9, number=16, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x18\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compute_cost', full_name='tensorflow.CostGraphDef.Node.compute_cost', index=10, number=9, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compute_time', full_name='tensorflow.CostGraphDef.Node.compute_time', index=11, number=14, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_time', full_name='tensorflow.CostGraphDef.Node.memory_time', index=12, number=15, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_final', full_name='tensorflow.CostGraphDef.Node.is_final', index=13, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='control_input', full_name='tensorflow.CostGraphDef.Node.control_input', index=14, number=8, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='inaccurate', full_name='tensorflow.CostGraphDef.Node.inaccurate', index=15, number=17, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_COSTGRAPHDEF_NODE_INPUTINFO, _COSTGRAPHDEF_NODE_OUTPUTINFO], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=261, serialized_end=935)
_COSTGRAPHDEF_AGGREGATEDCOST = _descriptor.Descriptor(name='AggregatedCost', full_name='tensorflow.CostGraphDef.AggregatedCost', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='cost', full_name='tensorflow.CostGraphDef.AggregatedCost.cost', index=0, number=1, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dimension', full_name='tensorflow.CostGraphDef.AggregatedCost.dimension', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=937, serialized_end=986)
_COSTGRAPHDEF = _descriptor.Descriptor(name='CostGraphDef', full_name='tensorflow.CostGraphDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='node', full_name='tensorflow.CostGraphDef.node', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cost', full_name='tensorflow.CostGraphDef.cost', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_COSTGRAPHDEF_NODE, _COSTGRAPHDEF_AGGREGATEDCOST], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=144, serialized_end=986)
_COSTGRAPHDEF_NODE_INPUTINFO.containing_type = _COSTGRAPHDEF_NODE
_COSTGRAPHDEF_NODE_OUTPUTINFO.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_COSTGRAPHDEF_NODE_OUTPUTINFO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_COSTGRAPHDEF_NODE_OUTPUTINFO.containing_type = _COSTGRAPHDEF_NODE
_COSTGRAPHDEF_NODE.fields_by_name['input_info'].message_type = _COSTGRAPHDEF_NODE_INPUTINFO
_COSTGRAPHDEF_NODE.fields_by_name['output_info'].message_type = _COSTGRAPHDEF_NODE_OUTPUTINFO
_COSTGRAPHDEF_NODE.containing_type = _COSTGRAPHDEF
_COSTGRAPHDEF_AGGREGATEDCOST.containing_type = _COSTGRAPHDEF
_COSTGRAPHDEF.fields_by_name['node'].message_type = _COSTGRAPHDEF_NODE
_COSTGRAPHDEF.fields_by_name['cost'].message_type = _COSTGRAPHDEF_AGGREGATEDCOST
DESCRIPTOR.message_types_by_name['CostGraphDef'] = _COSTGRAPHDEF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CostGraphDef = _reflection.GeneratedProtocolMessageType('CostGraphDef', (_message.Message,), {'Node': _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {'InputInfo': _reflection.GeneratedProtocolMessageType('InputInfo', (_message.Message,), {'DESCRIPTOR': _COSTGRAPHDEF_NODE_INPUTINFO, '__module__': 'tensorflow.core.framework.cost_graph_pb2'}), 'OutputInfo': _reflection.GeneratedProtocolMessageType('OutputInfo', (_message.Message,), {'DESCRIPTOR': _COSTGRAPHDEF_NODE_OUTPUTINFO, '__module__': 'tensorflow.core.framework.cost_graph_pb2'}), 'DESCRIPTOR': _COSTGRAPHDEF_NODE, '__module__': 'tensorflow.core.framework.cost_graph_pb2'}), 'AggregatedCost': _reflection.GeneratedProtocolMessageType('AggregatedCost', (_message.Message,), {'DESCRIPTOR': _COSTGRAPHDEF_AGGREGATEDCOST, '__module__': 'tensorflow.core.framework.cost_graph_pb2'}), 'DESCRIPTOR': _COSTGRAPHDEF, '__module__': 'tensorflow.core.framework.cost_graph_pb2'})
_sym_db.RegisterMessage(CostGraphDef)
_sym_db.RegisterMessage(CostGraphDef.Node)
_sym_db.RegisterMessage(CostGraphDef.Node.InputInfo)
_sym_db.RegisterMessage(CostGraphDef.Node.OutputInfo)
_sym_db.RegisterMessage(CostGraphDef.AggregatedCost)
DESCRIPTOR._options = None
_COSTGRAPHDEF_NODE.fields_by_name['host_temp_memory_size']._options = None
_COSTGRAPHDEF_NODE.fields_by_name['device_temp_memory_size']._options = None
_COSTGRAPHDEF_NODE.fields_by_name['device_persistent_memory_size']._options = None



from .pb.tensorflow.core.framework import tensor_shape_pb2
from .pb.tensorflow.core.framework import types_pb2
from typing import Sequence, Optional

from . import errors
from . import numpy_util

import numpy as np

# // We store the number of dimensions in byte 14, and the RepTag in byte 15.
# // Bytes [0..13] vary depending on the representation.
# // A value of 255 indicates unknown rank in the PartialTensorShape case.
# static constexpr uint8 kUnknownRank = 255;
kUnknownRank = 255

class TensorShape:
  def __init__(self, data_type: types_pb2.DataType = types_pb2.DT_INVALID):
    self._dims = []
    self._num_elements = 1
    self._data_type = data_type

  @classmethod
  def from_dims(cls, dims: Sequence[int]):
    self = cls()
    errors.raise_if_error(self.init_dims(dims))
    return self

  @classmethod
  def from_proto(cls, proto: tensor_shape_pb2.TensorShapeProto):
    self = PartialTensorShape() if proto.unknown_rank else cls()
    dims = [dim.size for dim in proto.dim]
    errors.raise_if_error(self.init_dims(dims))
    return self

  def as_proto(self, proto: tensor_shape_pb2.TensorShapeProto):
    proto.Clear()
    if self.unknown_rank():
      proto.unknown_rank = True
    else:
      for i in range(self.dims()):
        dim = proto.dim.add()
        dim.size = self.dim_size(i)

  def unknown_rank(self):
    return isinstance(self, PartialTensorShape) and self.ndims_byte() == kUnknownRank

  def to_list(self):
    return tuple(self._dims)

  def __repr__(self):
    return f"TensorShape(data_type={self.data_type()}, dtype={self.dtype()}, num_elements={self.num_elements()}, dims={self.to_list()})"

  def __iter__(self):
    return iter(self.to_list())

  def __len__(self):
    return len(self.to_list())

  def __getitem__(self, d):
    return self.to_list()[d]

  def max_dimensions(self):
    """Maximum number of dimensions in a tensor.
    It's 254 because 255 = kUnknownRank is used to represent unknown rank."""
    return 254

  def data_type(self) -> types_pb2.DataType:
    return self._data_type

  def dtype(self) -> Optional[np.dtype]:
    s, dtype = numpy_util.data_type_to_numpy_dtype(self.data_type())
    if s.ok():
      return dtype
    else:
      return None

  def set_data_type(self, data_type: types_pb2.DataType):
    self._data_type = data_type

  def ndims_byte(self) -> int:
    return len(self._dims)
  
  def dims(self) -> int:
    return len(self._dims)
  
  def num_elements(self) -> int:
    return self._num_elements
  
  def set_num_elements(self, n):
    self._num_elements = n
  
  def dim_size(self, d: int) -> int:
    return self._dims[d]

  def set_dim(self, d: int, size: int):
    assert d >= 0
    assert d < self.dims()
    self._dims[d] = size
  
  def init_dims(self, dim_sizes: Sequence[int]) -> errors.Status:
    self._dims.clear()
    self.set_num_elements(1)
    status = errors.Status.OK()
    for s in dim_sizes:
      status.update(self.add_dim_with_status(s))
      if not status.ok():
        return status
    return status

  def add_dim_with_status(self, size: int) -> errors.Status:
    if self.ndims_byte() >= self.max_dimensions():
      return errors.Internal("Too many dimensions in tensor")
    
    assert size >= 0
    new_num_elements = self.num_elements() * size
    if new_num_elements < 0:
      return errors.Internal("Encountered overflow when multiplying ",
                             self.num_elements(), " with ", size,
                             ", result: ", new_num_elements)

    self.unsafe_add_dim(size, new_num_elements)
    return errors.Status.OK()

  def unsafe_add_dim(self, size: int, new_num_elements: int):
    self._dims.append(size)
    self.set_num_elements(new_num_elements)


class PartialTensorShape(TensorShape):
  def ndims_byte(self) -> int:
    return kUnknownRank

    



'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....tensorflow.core.profiler.protobuf import diagnostics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/input_pipeline.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n6tensorflow/core/profiler/protobuf/input_pipeline.proto\x12\x13tensorflow.profiler\x1a\x19google/protobuf/any.proto\x1a3tensorflow/core/profiler/protobuf/diagnostics.proto"\x80\x03\n\x12BottleneckAnalysis\x12\x15\n\rinput_percent\x18\x07 \x01(\x01\x12\x16\n\x0eoutput_percent\x18\x08 \x01(\x01\x12\x14\n\x0cidle_percent\x18\t \x01(\x01\x12\x17\n\x0fcompute_percent\x18\n \x01(\x01\x12\x1c\n\x14input_classification\x18\x01 \x01(\t\x12\x17\n\x0finput_statement\x18\x02 \x01(\t\x12$\n\x1ckernel_launch_classification\x18\x03 \x01(\t\x12\x1f\n\x17kernel_launch_statement\x18\x04 \x01(\t\x12 \n\x18all_other_classification\x18\x05 \x01(\t\x12\x1b\n\x13all_other_statement\x18\x06 \x01(\t\x12)\n!device_collectives_classification\x18\x0b \x01(\t\x12$\n\x1cdevice_collectives_statement\x18\x0c \x01(\t"\\\n\x0bStepSummary\x12\x0f\n\x07average\x18\x01 \x01(\x01\x12\x1a\n\x12standard_deviation\x18\x02 \x01(\x01\x12\x0f\n\x07minimum\x18\x03 \x01(\x01\x12\x0f\n\x07maximum\x18\x04 \x01(\x01"\xe0\x02\n\x15PerGenericStepDetails\x12\x13\n\x0bstep_number\x18\x01 \x01(\x05\x12\x11\n\tstep_name\x18\x0e \x01(\t\x12\x14\n\x0cstep_time_ms\x18\x02 \x01(\x01\x12\x17\n\x0funknown_time_ms\x18\x03 \x01(\x01\x12\x1a\n\x12host_wait_input_ms\x18\x0b \x01(\x01\x12\x19\n\x11host_to_device_ms\x18\x0c \x01(\x01\x12\x11\n\toutput_ms\x18\x05 \x01(\x01\x12\x19\n\x11device_compute_ms\x18\x06 \x01(\x01\x12\x1b\n\x13device_to_device_ms\x18\x07 \x01(\x01\x12\x1d\n\x15device_collectives_ms\x18\r \x01(\x01\x12\x17\n\x0fhost_compute_ms\x18\x08 \x01(\x01\x12\x17\n\x0fhost_prepare_ms\x18\t \x01(\x01\x12\x17\n\x0fhost_compile_ms\x18\n \x01(\x01J\x04\x08\x04\x10\x05"\xa5\x01\n\x12InputTimeBreakdown\x12\x1d\n\x15demanded_file_read_us\x18\x01 \x01(\x01\x12\x1d\n\x15advanced_file_read_us\x18\x02 \x01(\x01\x12\x18\n\x10preprocessing_us\x18\x03 \x01(\x01\x12\x12\n\nenqueue_us\x18\x04 \x01(\x01\x12#\n\x1bunclassified_non_enqueue_us\x18\x05 \x01(\x01"\xa6\x01\n\x0eInputOpDetails\x12\x0f\n\x07op_name\x18\x01 \x01(\t\x12\r\n\x05count\x18\x02 \x01(\x04\x12\x12\n\ntime_in_ms\x18\x03 \x01(\x01\x12\x17\n\x0ftime_in_percent\x18\x04 \x01(\x01\x12\x17\n\x0fself_time_in_ms\x18\x05 \x01(\x01\x12\x1c\n\x14self_time_in_percent\x18\x06 \x01(\x01\x12\x10\n\x08category\x18\x07 \x01(\t"\x84\x01\n#InputPipelineAnalysisRecommendation\x12\x0f\n\x07details\x18\x01 \x03(\t\x121\n\x13bottleneck_analysis\x18\x02 \x01(\x0b2\x14.google.protobuf.Any\x12\x19\n\x11summary_next_step\x18\x03 \x01(\t"\x85\x06\n\x18GenericStepTimeBreakdown\x12A\n\x17unknown_time_ms_summary\x18\x01 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12D\n\x1ahost_wait_input_ms_summary\x18\t \x01(\x0b2 .tensorflow.profiler.StepSummary\x12C\n\x19host_to_device_ms_summary\x18\n \x01(\x0b2 .tensorflow.profiler.StepSummary\x12:\n\x10input_ms_summary\x18\x0b \x01(\x0b2 .tensorflow.profiler.StepSummary\x12;\n\x11output_ms_summary\x18\x03 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12C\n\x19device_compute_ms_summary\x18\x04 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12E\n\x1bdevice_to_device_ms_summary\x18\x05 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12G\n\x1ddevice_collectives_ms_summary\x18\x0c \x01(\x0b2 .tensorflow.profiler.StepSummary\x12A\n\x17host_compute_ms_summary\x18\x06 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12A\n\x17host_prepare_ms_summary\x18\x07 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12A\n\x17host_compile_ms_summary\x18\x08 \x01(\x0b2 .tensorflow.profiler.StepSummaryJ\x04\x08\x02\x10\x03"\x8a\x05\n\x1bInputPipelineAnalysisResult\x12\x15\n\rhardware_type\x18\t \x01(\t\x12;\n\x11step_time_summary\x18\x02 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12?\n\x15input_percent_summary\x18\x03 \x01(\x0b2 .tensorflow.profiler.StepSummary\x12\x15\n\rinput_percent\x18\x0b \x01(\x01\x12\x16\n\x0eoutput_percent\x18\r \x01(\x01\x12\x14\n\x0cidle_percent\x18\x0e \x01(\x01\x12\x17\n\x0fcompute_percent\x18\x0f \x01(\x01\x12*\n\x0cstep_details\x18\x04 \x03(\x0b2\x14.google.protobuf.Any\x12E\n\x14input_time_breakdown\x18\x05 \x01(\x0b2\'.tensorflow.profiler.InputTimeBreakdown\x12=\n\x10input_op_details\x18\x06 \x03(\x0b2#.tensorflow.profiler.InputOpDetails\x12P\n\x0erecommendation\x18\x07 \x01(\x0b28.tensorflow.profiler.InputPipelineAnalysisRecommendation\x121\n\x13step_time_breakdown\x18\x08 \x01(\x0b2\x14.google.protobuf.Any\x125\n\x0bdiagnostics\x18\x0c \x01(\x0b2 .tensorflow.profiler.DiagnosticsJ\x04\x08\x01\x10\x02J\x04\x08\n\x10\x0bb\x06proto3', dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2.DESCRIPTOR])
_BOTTLENECKANALYSIS = _descriptor.Descriptor(name='BottleneckAnalysis', full_name='tensorflow.profiler.BottleneckAnalysis', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='input_percent', full_name='tensorflow.profiler.BottleneckAnalysis.input_percent', index=0, number=7, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_percent', full_name='tensorflow.profiler.BottleneckAnalysis.output_percent', index=1, number=8, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='idle_percent', full_name='tensorflow.profiler.BottleneckAnalysis.idle_percent', index=2, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compute_percent', full_name='tensorflow.profiler.BottleneckAnalysis.compute_percent', index=3, number=10, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_classification', full_name='tensorflow.profiler.BottleneckAnalysis.input_classification', index=4, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_statement', full_name='tensorflow.profiler.BottleneckAnalysis.input_statement', index=5, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kernel_launch_classification', full_name='tensorflow.profiler.BottleneckAnalysis.kernel_launch_classification', index=6, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kernel_launch_statement', full_name='tensorflow.profiler.BottleneckAnalysis.kernel_launch_statement', index=7, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_other_classification', full_name='tensorflow.profiler.BottleneckAnalysis.all_other_classification', index=8, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_other_statement', full_name='tensorflow.profiler.BottleneckAnalysis.all_other_statement', index=9, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_classification', full_name='tensorflow.profiler.BottleneckAnalysis.device_collectives_classification', index=10, number=11, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_statement', full_name='tensorflow.profiler.BottleneckAnalysis.device_collectives_statement', index=11, number=12, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=160, serialized_end=544)
_STEPSUMMARY = _descriptor.Descriptor(name='StepSummary', full_name='tensorflow.profiler.StepSummary', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='average', full_name='tensorflow.profiler.StepSummary.average', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='standard_deviation', full_name='tensorflow.profiler.StepSummary.standard_deviation', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='minimum', full_name='tensorflow.profiler.StepSummary.minimum', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='maximum', full_name='tensorflow.profiler.StepSummary.maximum', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=546, serialized_end=638)
_PERGENERICSTEPDETAILS = _descriptor.Descriptor(name='PerGenericStepDetails', full_name='tensorflow.profiler.PerGenericStepDetails', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_number', full_name='tensorflow.profiler.PerGenericStepDetails.step_number', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_name', full_name='tensorflow.profiler.PerGenericStepDetails.step_name', index=1, number=14, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_time_ms', full_name='tensorflow.profiler.PerGenericStepDetails.step_time_ms', index=2, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unknown_time_ms', full_name='tensorflow.profiler.PerGenericStepDetails.unknown_time_ms', index=3, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_wait_input_ms', full_name='tensorflow.profiler.PerGenericStepDetails.host_wait_input_ms', index=4, number=11, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_to_device_ms', full_name='tensorflow.profiler.PerGenericStepDetails.host_to_device_ms', index=5, number=12, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_ms', full_name='tensorflow.profiler.PerGenericStepDetails.output_ms', index=6, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_compute_ms', full_name='tensorflow.profiler.PerGenericStepDetails.device_compute_ms', index=7, number=6, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_to_device_ms', full_name='tensorflow.profiler.PerGenericStepDetails.device_to_device_ms', index=8, number=7, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_ms', full_name='tensorflow.profiler.PerGenericStepDetails.device_collectives_ms', index=9, number=13, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compute_ms', full_name='tensorflow.profiler.PerGenericStepDetails.host_compute_ms', index=10, number=8, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_prepare_ms', full_name='tensorflow.profiler.PerGenericStepDetails.host_prepare_ms', index=11, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compile_ms', full_name='tensorflow.profiler.PerGenericStepDetails.host_compile_ms', index=12, number=10, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=641, serialized_end=993)
_INPUTTIMEBREAKDOWN = _descriptor.Descriptor(name='InputTimeBreakdown', full_name='tensorflow.profiler.InputTimeBreakdown', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='demanded_file_read_us', full_name='tensorflow.profiler.InputTimeBreakdown.demanded_file_read_us', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='advanced_file_read_us', full_name='tensorflow.profiler.InputTimeBreakdown.advanced_file_read_us', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='preprocessing_us', full_name='tensorflow.profiler.InputTimeBreakdown.preprocessing_us', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='enqueue_us', full_name='tensorflow.profiler.InputTimeBreakdown.enqueue_us', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unclassified_non_enqueue_us', full_name='tensorflow.profiler.InputTimeBreakdown.unclassified_non_enqueue_us', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=996, serialized_end=1161)
_INPUTOPDETAILS = _descriptor.Descriptor(name='InputOpDetails', full_name='tensorflow.profiler.InputOpDetails', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op_name', full_name='tensorflow.profiler.InputOpDetails.op_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='count', full_name='tensorflow.profiler.InputOpDetails.count', index=1, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='time_in_ms', full_name='tensorflow.profiler.InputOpDetails.time_in_ms', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='time_in_percent', full_name='tensorflow.profiler.InputOpDetails.time_in_percent', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='self_time_in_ms', full_name='tensorflow.profiler.InputOpDetails.self_time_in_ms', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='self_time_in_percent', full_name='tensorflow.profiler.InputOpDetails.self_time_in_percent', index=5, number=6, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='category', full_name='tensorflow.profiler.InputOpDetails.category', index=6, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1164, serialized_end=1330)
_INPUTPIPELINEANALYSISRECOMMENDATION = _descriptor.Descriptor(name='InputPipelineAnalysisRecommendation', full_name='tensorflow.profiler.InputPipelineAnalysisRecommendation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='details', full_name='tensorflow.profiler.InputPipelineAnalysisRecommendation.details', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bottleneck_analysis', full_name='tensorflow.profiler.InputPipelineAnalysisRecommendation.bottleneck_analysis', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='summary_next_step', full_name='tensorflow.profiler.InputPipelineAnalysisRecommendation.summary_next_step', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1333, serialized_end=1465)
_GENERICSTEPTIMEBREAKDOWN = _descriptor.Descriptor(name='GenericStepTimeBreakdown', full_name='tensorflow.profiler.GenericStepTimeBreakdown', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='unknown_time_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.unknown_time_ms_summary', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_wait_input_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.host_wait_input_ms_summary', index=1, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_to_device_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.host_to_device_ms_summary', index=2, number=10, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.input_ms_summary', index=3, number=11, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.output_ms_summary', index=4, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_compute_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.device_compute_ms_summary', index=5, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_to_device_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.device_to_device_ms_summary', index=6, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.device_collectives_ms_summary', index=7, number=12, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compute_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.host_compute_ms_summary', index=8, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_prepare_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.host_prepare_ms_summary', index=9, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compile_ms_summary', full_name='tensorflow.profiler.GenericStepTimeBreakdown.host_compile_ms_summary', index=10, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1468, serialized_end=2241)
_INPUTPIPELINEANALYSISRESULT = _descriptor.Descriptor(name='InputPipelineAnalysisResult', full_name='tensorflow.profiler.InputPipelineAnalysisResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='hardware_type', full_name='tensorflow.profiler.InputPipelineAnalysisResult.hardware_type', index=0, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_time_summary', full_name='tensorflow.profiler.InputPipelineAnalysisResult.step_time_summary', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_percent_summary', full_name='tensorflow.profiler.InputPipelineAnalysisResult.input_percent_summary', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_percent', full_name='tensorflow.profiler.InputPipelineAnalysisResult.input_percent', index=3, number=11, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_percent', full_name='tensorflow.profiler.InputPipelineAnalysisResult.output_percent', index=4, number=13, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='idle_percent', full_name='tensorflow.profiler.InputPipelineAnalysisResult.idle_percent', index=5, number=14, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compute_percent', full_name='tensorflow.profiler.InputPipelineAnalysisResult.compute_percent', index=6, number=15, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_details', full_name='tensorflow.profiler.InputPipelineAnalysisResult.step_details', index=7, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_time_breakdown', full_name='tensorflow.profiler.InputPipelineAnalysisResult.input_time_breakdown', index=8, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_op_details', full_name='tensorflow.profiler.InputPipelineAnalysisResult.input_op_details', index=9, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='recommendation', full_name='tensorflow.profiler.InputPipelineAnalysisResult.recommendation', index=10, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_time_breakdown', full_name='tensorflow.profiler.InputPipelineAnalysisResult.step_time_breakdown', index=11, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='diagnostics', full_name='tensorflow.profiler.InputPipelineAnalysisResult.diagnostics', index=12, number=12, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2244, serialized_end=2894)
_INPUTPIPELINEANALYSISRECOMMENDATION.fields_by_name['bottleneck_analysis'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['unknown_time_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['host_wait_input_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['host_to_device_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['input_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['output_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['device_compute_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['device_to_device_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['device_collectives_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['host_compute_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['host_prepare_ms_summary'].message_type = _STEPSUMMARY
_GENERICSTEPTIMEBREAKDOWN.fields_by_name['host_compile_ms_summary'].message_type = _STEPSUMMARY
_INPUTPIPELINEANALYSISRESULT.fields_by_name['step_time_summary'].message_type = _STEPSUMMARY
_INPUTPIPELINEANALYSISRESULT.fields_by_name['input_percent_summary'].message_type = _STEPSUMMARY
_INPUTPIPELINEANALYSISRESULT.fields_by_name['step_details'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INPUTPIPELINEANALYSISRESULT.fields_by_name['input_time_breakdown'].message_type = _INPUTTIMEBREAKDOWN
_INPUTPIPELINEANALYSISRESULT.fields_by_name['input_op_details'].message_type = _INPUTOPDETAILS
_INPUTPIPELINEANALYSISRESULT.fields_by_name['recommendation'].message_type = _INPUTPIPELINEANALYSISRECOMMENDATION
_INPUTPIPELINEANALYSISRESULT.fields_by_name['step_time_breakdown'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INPUTPIPELINEANALYSISRESULT.fields_by_name['diagnostics'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2._DIAGNOSTICS
DESCRIPTOR.message_types_by_name['BottleneckAnalysis'] = _BOTTLENECKANALYSIS
DESCRIPTOR.message_types_by_name['StepSummary'] = _STEPSUMMARY
DESCRIPTOR.message_types_by_name['PerGenericStepDetails'] = _PERGENERICSTEPDETAILS
DESCRIPTOR.message_types_by_name['InputTimeBreakdown'] = _INPUTTIMEBREAKDOWN
DESCRIPTOR.message_types_by_name['InputOpDetails'] = _INPUTOPDETAILS
DESCRIPTOR.message_types_by_name['InputPipelineAnalysisRecommendation'] = _INPUTPIPELINEANALYSISRECOMMENDATION
DESCRIPTOR.message_types_by_name['GenericStepTimeBreakdown'] = _GENERICSTEPTIMEBREAKDOWN
DESCRIPTOR.message_types_by_name['InputPipelineAnalysisResult'] = _INPUTPIPELINEANALYSISRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
BottleneckAnalysis = _reflection.GeneratedProtocolMessageType('BottleneckAnalysis', (_message.Message,), {'DESCRIPTOR': _BOTTLENECKANALYSIS, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(BottleneckAnalysis)
StepSummary = _reflection.GeneratedProtocolMessageType('StepSummary', (_message.Message,), {'DESCRIPTOR': _STEPSUMMARY, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(StepSummary)
PerGenericStepDetails = _reflection.GeneratedProtocolMessageType('PerGenericStepDetails', (_message.Message,), {'DESCRIPTOR': _PERGENERICSTEPDETAILS, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(PerGenericStepDetails)
InputTimeBreakdown = _reflection.GeneratedProtocolMessageType('InputTimeBreakdown', (_message.Message,), {'DESCRIPTOR': _INPUTTIMEBREAKDOWN, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(InputTimeBreakdown)
InputOpDetails = _reflection.GeneratedProtocolMessageType('InputOpDetails', (_message.Message,), {'DESCRIPTOR': _INPUTOPDETAILS, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(InputOpDetails)
InputPipelineAnalysisRecommendation = _reflection.GeneratedProtocolMessageType('InputPipelineAnalysisRecommendation', (_message.Message,), {'DESCRIPTOR': _INPUTPIPELINEANALYSISRECOMMENDATION, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(InputPipelineAnalysisRecommendation)
GenericStepTimeBreakdown = _reflection.GeneratedProtocolMessageType('GenericStepTimeBreakdown', (_message.Message,), {'DESCRIPTOR': _GENERICSTEPTIMEBREAKDOWN, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(GenericStepTimeBreakdown)
InputPipelineAnalysisResult = _reflection.GeneratedProtocolMessageType('InputPipelineAnalysisResult', (_message.Message,), {'DESCRIPTOR': _INPUTPIPELINEANALYSISRESULT, '__module__': 'tensorflow.core.profiler.protobuf.input_pipeline_pb2'})
_sym_db.RegisterMessage(InputPipelineAnalysisResult)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/cluster.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x1aorg.tensorflow.distruntimeB\rClusterProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n&tensorflow/core/protobuf/cluster.proto\x12\ntensorflow"r\n\x06JobDef\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x05tasks\x18\x02 \x03(\x0b2\x1d.tensorflow.JobDef.TasksEntry\x1a,\n\nTasksEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01"-\n\nClusterDef\x12\x1f\n\x03job\x18\x01 \x03(\x0b2\x12.tensorflow.JobDefB\x87\x01\n\x1aorg.tensorflow.distruntimeB\rClusterProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3')
_JOBDEF_TASKSENTRY = _descriptor.Descriptor(name='TasksEntry', full_name='tensorflow.JobDef.TasksEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.JobDef.TasksEntry.key', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.JobDef.TasksEntry.value', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=124, serialized_end=168)
_JOBDEF = _descriptor.Descriptor(name='JobDef', full_name='tensorflow.JobDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.JobDef.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tasks', full_name='tensorflow.JobDef.tasks', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_JOBDEF_TASKSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=54, serialized_end=168)
_CLUSTERDEF = _descriptor.Descriptor(name='ClusterDef', full_name='tensorflow.ClusterDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job', full_name='tensorflow.ClusterDef.job', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=170, serialized_end=215)
_JOBDEF_TASKSENTRY.containing_type = _JOBDEF
_JOBDEF.fields_by_name['tasks'].message_type = _JOBDEF_TASKSENTRY
_CLUSTERDEF.fields_by_name['job'].message_type = _JOBDEF
DESCRIPTOR.message_types_by_name['JobDef'] = _JOBDEF
DESCRIPTOR.message_types_by_name['ClusterDef'] = _CLUSTERDEF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
JobDef = _reflection.GeneratedProtocolMessageType('JobDef', (_message.Message,), {'TasksEntry': _reflection.GeneratedProtocolMessageType('TasksEntry', (_message.Message,), {'DESCRIPTOR': _JOBDEF_TASKSENTRY, '__module__': 'tensorflow.core.protobuf.cluster_pb2'}), 'DESCRIPTOR': _JOBDEF, '__module__': 'tensorflow.core.protobuf.cluster_pb2'})
_sym_db.RegisterMessage(JobDef)
_sym_db.RegisterMessage(JobDef.TasksEntry)
ClusterDef = _reflection.GeneratedProtocolMessageType('ClusterDef', (_message.Message,), {'DESCRIPTOR': _CLUSTERDEF, '__module__': 'tensorflow.core.protobuf.cluster_pb2'})
_sym_db.RegisterMessage(ClusterDef)
DESCRIPTOR._options = None
_JOBDEF_TASKSENTRY._options = None
